@@ -1,3 +1,4 @@
+import json
 from abc import ABC
 from dataclasses import dataclass
 from typing import List
@@ -11,3 +12,7 @@ class AbstractConfig(ABC):
     filename: str
     experiment_class = None  # type: ignore
     experiment_module: str
+
+    def to_json(self) -> str:
+        """return a dictionary of instance variables"""
+        return json.dumps(vars(self), indent=4)
